.. _api_geometry_circle:

.. currentmodule:: microstructpy.geometry

microstructpy.geometry.Circle
=============================

.. autoclass:: Circle
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance: